Alice class

Constructors

Alice({GlobalKey<NavigatorState>? navigatorKey, bool showNotification = true, bool darkTheme = false, String notificationIcon = "@mipmap/ic_launcher"})
Creates alice instance.

Properties

darkTheme bool
Should inspector be opened on device shake (works only with physical with sensors) Should inspector use dark theme
final
hashCode int
The hash code for this object.
no setterinherited
notificationIcon String
Icon url for notification
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNotification bool
Should user be notified with notification if there's new request catched by Alice
final

Methods

getDioInterceptor() AliceDioInterceptor
Get Dio interceptor which should be applied to Dio instance.
getNavigatorKey() GlobalKey<NavigatorState>?
Get currently used navigation key
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNavigatorKey(GlobalKey<NavigatorState> navigatorKey) → void
Set custom navigation key. This will help if there's route library.
showInspector() → void
Opens Http calls inspector. This will navigate user to the new fullscreen page where all listened http calls can be viewed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited